Synode | Folio Intranet

Excepturi sint occaecati Share Edit

# Synode

Das katholische Kirchenparlament im Kanton Zürich.

Die Synode ist die Vertretung der in Kirchgemeinden gegliederten Römisch-katholischen Körperschaft. Jede Kirchgemeinde wählt auf die Dauer von vier Jahren mindestens ein Synodenmitglied. Grösseren Kirchgemeinden steht für je 6000 Mitglieder ein Synodenmitglied zu.

Sekretariat Synode: Hirschengraben 70, 8001 Zürich Telefon 044 266 12 20, Telefax 044 266 12 21 synode@zh.kath.ch

zuletzt verändert: 20.03.2015 08:24

## Sitzungen

Mehr…

## Adressen

Mitglieder und Kommissionen der Synode Mehr…

## Parlamentarische Instrumente

Hängige und bearbeitete parlamentarische Vorstösse Mehr…

## Termine

Mehr…

## Mitarbeitende

synode@zh.kath.ch, 044 266 12 20 Mehr…

## Einführung für Synodale

Veranstaltung der Synoden-Geschäftsleitung

Die Geschäftsleitung der Synode hat Ende September an zwei Veranstaltungen insgesamt gut 80 Synodale - neu gewählte und “alte Hasen” - in die Grundsätze der Parlamentsarbeit eingeweiht.

Alle Unterlagen der Referate der Veranstaltungen vom 17. und 22. September 2011 finden Sie hier.

zuletzt verändert: 23.09.2011 13:48

## Informationsbroschüre für Interessierte am Synodenamt

Hrsg. Geschäftsleitung Synode PDF document icon Infobroschüre Synodenamt.pdf — PDF document, 823 KB (843206 bytes)

zuletzt verändert: 22.08.2014 15:42

## Selbstevaluation

Erfahrungen mit der gesamthaften Beratung der Subventionsanträge 2014 PDF document icon gesamthafte Beratung der Subventionsanträge 2014.pdf — PDF document, 384 KB (393318 bytes)

zuletzt verändert: 09.12.2014 11:05

## Besinnungstag in Sachseln

Mehr…

### Excepturi sint occaecati